sample_test_fail_all_setup_20141211_225908

### sample_config1 : test1

Result | Function execution time | Total execution time
--- | --- | ---
Skipped | Skipped | Skipped

Other messages: setup() failed. See below for the trace. Traceback (most recent call last): File "/home/jehrlich/workspace/zopkio/zopkio/test_runner.py", line 302, in _execute_single_test self.deployment_module.setup() File "/home/jehrlich/workspace/zopkio/test/samples/sample_test_fail_all_setup.py", line 38, in setup raise ValueError("Random exception") ValueError: Random exception